Class: RemLint::Vocabulary::Keyword
- Inherits:
-
Struct
- Object
- Struct
- RemLint::Vocabulary::Keyword
- Defined in:
- lib/remlint/vocabulary.rb
Instance Attribute Summary collapse
-
#minlen ⇒ Object
Returns the value of attribute minlen.
-
#name ⇒ Object
Returns the value of attribute name.
-
#type ⇒ Object
Returns the value of attribute type.
Instance Method Summary collapse
-
#body? ⇒ Boolean
MSG,MSF,RUN,CAL,SATISFY,SPECIAL,PS,PSFILE-- the token that ends a trigger and starts the reminder body. - #clause? ⇒ Boolean
Instance Attribute Details
#minlen ⇒ Object
Returns the value of attribute minlen
29 30 31 |
# File 'lib/remlint/vocabulary.rb', line 29 def minlen @minlen end |
#name ⇒ Object
Returns the value of attribute name
29 30 31 |
# File 'lib/remlint/vocabulary.rb', line 29 def name @name end |
#type ⇒ Object
Returns the value of attribute type
29 30 31 |
# File 'lib/remlint/vocabulary.rb', line 29 def type @type end |
Instance Method Details
#body? ⇒ Boolean
MSG, MSF, RUN, CAL, SATISFY, SPECIAL, PS, PSFILE --
the token that ends a trigger and starts the reminder body.
36 37 38 |
# File 'lib/remlint/vocabulary.rb', line 36 def body? type == "T_RemType" end |
#clause? ⇒ Boolean
30 31 32 |
# File 'lib/remlint/vocabulary.rb', line 30 def clause? CLAUSE_TYPES.include?(type) end |